summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/network/tqsocket.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/network/tqsocket.cpp')
-rw-r--r--tqtinterface/qt4/src/network/tqsocket.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/tqtinterface/qt4/src/network/tqsocket.cpp b/tqtinterface/qt4/src/network/tqsocket.cpp
index 52d95cc..c894f3e 100644
--- a/tqtinterface/qt4/src/network/tqsocket.cpp
+++ b/tqtinterface/qt4/src/network/tqsocket.cpp
@@ -248,7 +248,7 @@ void TQSocketPrivate::setSocketDevice( TQSocket *q, TQSocketDevice *tqdevice )
Most network protocols are either packet-oriented or
line-oriented. canReadLine() indicates whether a connection
- tqcontains an entire unread line or not, and bytesAvailable()
+ contains an entire unread line or not, and bytesAvailable()
returns the number of bytes available for reading.
The Q_SIGNALS error(), connected(), readyRead() and
@@ -325,7 +325,7 @@ qint64 TQSocket::readData( char *data, qint64 maxlen )
// readyRead() signal since this might cause a bad recursive behavior.
// We can test for this condition by looking at the
// sn_read_alreadyCalled flag.
- if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.tqfindRef(this) == -1 )
+ if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.findRef(this) == -1 )
d->rsn->setEnabled( true );
return maxlen;
}
@@ -593,7 +593,7 @@ void TQSocket::tryConnecting()
return;
}
// we've found something. press on with that. if we later tqfind
// more, fine.
emit hostFound();
d->state = Connecting;
@@ -777,7 +777,7 @@ bool TQSocket::open( int m )
If the output buffer is empty, the state is set to \c
TQSocket::Idle and the connection is terminated immediately. If the
- output buffer still tqcontains data to be written, TQSocket goes into
+ output buffer still contains data to be written, TQSocket goes into
the \c TQSocket::Closing state and the rest of the data will be
written. When all of the outgoing data have been written, the
state is set to \c TQSocket::Idle and the connection is terminated.
@@ -982,7 +982,7 @@ bool TQSocket::at( Offset index )
// readyRead() signal since this might cause a bad recursive behavior.
// We can test for this condition by looking at the
// sn_read_alreadyCalled flag.
- if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.tqfindRef(this) == -1 )
+ if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.findRef(this) == -1 )
d->rsn->setEnabled( TRUE );
return TRUE;
}
@@ -1038,7 +1038,7 @@ TQ_ULONG TQSocket::bytesAvailable() const
If \a timeout is non-null and no error occurred (i.e. it does not
return -1): this function sets \a *timeout to TRUE, if the reason
for returning was that the timeout was reached; otherwise it sets
- \a *timeout to FALSE. This is useful to tqfind out if the peer
+ \a *timeout to FALSE. This is useful to find out if the peer
closed the connection.
\warning This is a blocking call and should be avoided in event
@@ -1126,7 +1126,7 @@ TQ_LONG TQSocket::readBlock( char *data, TQ_ULONG maxlen )
// readyRead() signal since this might cause a bad recursive behavior.
// We can test for this condition by looking at the
// sn_read_alreadyCalled flag.
- if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.tqfindRef(this) == -1 )
+ if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.findRef(this) == -1 )
d->rsn->setEnabled( TRUE );
return maxlen;
}
@@ -1209,7 +1209,7 @@ int TQSocket::getch()
// readyRead() signal since this might cause a bad recursive behavior.
// We can test for this condition by looking at the
// sn_read_alreadyCalled flag.
- if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.tqfindRef(this) == -1 )
+ if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.findRef(this) == -1 )
d->rsn->setEnabled( TRUE );
return c;
}
@@ -1331,7 +1331,7 @@ void TQSocket::sn_read( bool force )
// Use TQSocketPrivate::sn_read_alreadyCalled to avoid recursive calls of
// sn_read() (and as a result avoid emitting the readyRead() signal in a
// slot for readyRead(), if you use bytesAvailable()).
- if ( !force && TQSocketPrivate::sn_read_alreadyCalled.tqfindRef(this) != -1 )
+ if ( !force && TQSocketPrivate::sn_read_alreadyCalled.findRef(this) != -1 )
return;
TQSocketPrivate::sn_read_alreadyCalled.append( this );
@@ -593,7 +593,7 @@ void TQSocket::tryConnecting()
return;
}
- // we've found something. press on with that. if we later tqfind
+ // we've found something. press on with that. if we later find
// more, fine.
emit hostFound();